LoginScope class

Inheritance

Constructors

LoginScope({Key? key, required Uri serverUrl, required Uri callbackUrl, required String oauthClientId, required Widget builder(BuildContext context), String scope = fullOAuthScope, void onAuthenticated(String returnUrl)?, Widget signInBuilder(BuildContext context, bool isCancelled, void signIn(String? provider))?, Map<String, String>? extraQueryParams, OAuthSessionManager? session, Client? client, bool preferEphemeralAuthSession = false, FutureOr<void> onSessionReady()?, WidgetBuilder? loadingBuilder})
const

Properties

builder Widget Function(BuildContext context)
final
callbackUrl Uri
final
client → Client?
final
extraQueryParams Map<String, String>?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingBuilder WidgetBuilder?
final
oauthClientId String
final
onAuthenticated → void Function(String returnUrl)?
final
onSessionReady FutureOr<void> Function()?
final
preferEphemeralAuthSession bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope String
final
serverUrl Uri
final
session OAuthSessionManager?
final
signInBuilder Widget Function(BuildContext context, bool isCancelled, void signIn(String? provider))?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited