MeshagentAuth class

Constructors

MeshagentAuth()

Properties

expiration DateTime?
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAccessToken() String?
getRefreshToken() String?
getUser() Map<String, dynamic>?
isExpired() bool
isLoggedIn() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAccessToken(String? token) → void
setExpiration(DateTime? expiration) → void
setExpiresIn(int? expiresIn) → void
setRefreshToken(String? refreshToken) → void
setUser(Map<String, dynamic>? user) → void
signOut() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

current MeshagentAuth
getter/setter pair