PkceGenerator class

Generates PKCE pairs per RFC 7636, with injectable dependencies.

Constructors

PkceGenerator({RandomBytesSource? rng, Hasher? hasher})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generate({int verifierLength = 64}) PkcePair
Generate a PKCE pair. verifierLength must be 43..128.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

maxVerifierLength → const int
minVerifierLength → const int