SharedProfileInfo class

Constructors

SharedProfileInfo({required String id, String? firstName, String? lastName, String? email})
const

Properties

displayName String
no setter
email String?
final
firstName String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
lastName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited