SharedProfileSession class

Constructors

SharedProfileSession({String? accessToken, String? refreshToken, int? expiresAt, String tokenType = "Bearer", String? scope, String? idToken})
const

Properties

accessToken String?
final
expiresAt int?
final
expiresAtUtc DateTime?
no setter
hasAccessToken bool
no setter
hashCode int
The hash code for this object.
no setterinherited
idToken String?
final
refreshToken String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope String?
final
tokenType String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited