setActiveSharedProfileInFile function
Implementation
Future<SharedProfile> setActiveSharedProfileInFile({required Object file, required String userId}) async {
throw UnsupportedError("Shared profiles are only available in native desktop apps.");
}
Future<SharedProfile> setActiveSharedProfileInFile({required Object file, required String userId}) async {
throw UnsupportedError("Shared profiles are only available in native desktop apps.");
}